clear
close all

%%
% Tight subplot.
% This function makes subplots to cover the whole plot area.
% See https://www.mathworks.com/matlabcentral/fileexchange/39664-subtightplot
subplot = @(m,n,p) subtightplot (m, n, p, [0.08 0.05], [0.1 0.04], [0.04 0.01]);

%%
% General parameters
T = 1; % period length
np = 1;  % number of periods to consider
ppp = 1000;  % number of sample points per period for "continuous" plot 
Fs = 32;  % the sampling freqency in Hertz
t0 = 0;  % initial time sample of the signal

%%
% Generate "continuous" time data for plotting
t1 = np*T;
tc = linspace(t0,t1,np*ppp+1);  % linspace includes the interval end

%%
% Signal
% Single harmonic, frequency in Hz
f0 = 10;
% Continuous form
xc = sin(2*pi/T*f0*tc);
%%
% Now let us sample the signal
% The sampling period
Ts = 1/Fs;
% The number of samples is given by the length of the observed signal, i.e.
% by the time difference from `t0` to `t1`
N = (t1-t0)*Fs;
% Determine the sampling points
k = 0:(N-1);
xs = sin(2*pi*f0*k*Ts);

xfft = fft(xs);
Nhalf = floor(N/2);
xfft2 = [xfft(1:Nhalf), zeros(1, N+1), xfft(Nhalf+2:end)];

f = figure('Name', 'Figure 1', ...
    'Units', 'normalized', 'OuterPosition',[0 0 1 1]);
subplot(4,1,1);
plot(tc, xc, '-', k*Ts, xs, 'o');
xlabel('t [s]');
ylabel('f(t)');
title(sprintf('Original signal, sampled with f_s=%d Hz', Fs));

subplot(4,1,2);
stem(0:(N-1), abs(xfft/N));
xlim([0,N-1]);
xlabel('f [Hz]');
ylabel('|P_2(f)|');
title('Zero-padded two-sided original spectrum');

subplot(4,1,3);
L = 2*N;
stem(0:(L-1),abs(xfft2/L));
xlim([0,L-1]);
xlabel('f [Hz]');
ylabel('|P_2(f)|');
title('Zero-padded two-sided spectrum, resampled to 2*f_s');

subplot(4,1,4);
xr = real(ifft(xfft));
xr2 = 2*real(ifft(xfft2));
% Determine the sampling points for the banlimited interpolated signal
Ts2 = 1/(2*Fs);
k2 = 0:(L-1);
plot(tc, xc, '--', k2*Ts2, xr2, '.', k*Ts, xr, 'o');
xlabel('t [s]');
ylabel('f(t)');
title('Bandlimited interpolation to 2*f_s');


