clear all
close all

N = 1000; % number of samples
Fs = 1000; % sampling frequency
f1 = 137; % 1. frequency
f2 = 147; % 2. frequency
tk = (0:(N-1))/Fs; % sampling times
f = sin(2*pi*f1*tk) + 0.4*sin(2*pi*f2*tk); % sampled signal

%%
% Original data
%
F = fft(f);
aF = abs(F(1:501));  % Amplitudes, one-sided spectrum
freq = 0:500;

figure(1);
plot(freq, aF);
xlim([100,200]);
ylim([0,100]);
xlabel('Frequency [Hz]');
title('Original FFT');

%%
% Zero-padding!
%
L = 4*N;
Fn = fft(f,L);
aFn = abs(Fn(1:L/2+1));
freqn = (0:L/2)*Fs/L;

figure(2);
plot(freqn, aFn);
xlim([100,200]);
ylim([0,100]);
xlabel('Frequency [Hz]');
title('Zero-padded FFT');

%%
% Rectangular window on first 200 components
L = 70;
fwa = f;
fwa(L+1:end) = 0;

% The rectangular window data
w = ones(1,N);
w(L+1:end) = 0;

figure(3);
subplot(2,1,1);
plot(tk, f, tk, w);
legend('f(t)', 'window');
title('Original signal');
subplot(2,1,2);
plot(tk, fwa);
title('Windowed sigal');

Fwa = fft(fwa);
aFwa = abs(Fwa(1:501));

figure(4);
plot(freq, aFwa);
xlim([100,200]);
ylim([0,100]);
xlabel('Frequency [Hz]');
title('FFT of windowed f(t)');

%%
% Limit the FFT to the first 200 coeffients
% Corresponds to `fwb` in the lecture slides
L = 200;
Fwb = fft(fwa,L);
aFwb = abs(Fwb(1:L/2+1));

freqb = (0:L/2)*Fs/L;

figure(5);
plot(freqb, aFwb);
xlim([100,200]);
ylim([0,100]);
xlabel('Frequency [Hz]');
title('FFT of truncated f(t)');








